Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(286)

Unified Diff: content/browser/renderer_host/compositor_impl_android.h

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: android-vulkan Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/compositor_impl_android.h
diff --git a/content/browser/renderer_host/compositor_impl_android.h b/content/browser/renderer_host/compositor_impl_android.h
index 6a71b7a46303e3f187e4674485e7039c4a4f2fda..0c853231f492821aa9dd0e0c42c0abdbdad1b523 100644
--- a/content/browser/renderer_host/compositor_impl_android.h
+++ b/content/browser/renderer_host/compositor_impl_android.h
@@ -35,6 +35,7 @@ namespace cc {
class Display;
class Layer;
class LayerTreeHost;
+class OutputSurface;
class SurfaceIdAllocator;
class SurfaceManager;
class VulkanContextProvider;
@@ -98,9 +99,9 @@ class CONTENT_EXPORT CompositorImpl
const gfx::Vector2dF& elastic_overscroll_delta,
float page_scale,
float top_controls_delta) override {}
- void RequestNewOutputSurface() override;
- void DidInitializeOutputSurface() override;
- void DidFailToInitializeOutputSurface() override;
+ void RequestNewCompositorFrameSink() override;
+ void DidInitializeCompositorFrameSink() override;
+ void DidFailToInitializeCompositorFrameSink() override;
void WillCommit() override {}
void DidCommit() override;
void DidCommitAndDrawFrame() override {}
@@ -121,7 +122,7 @@ class CONTENT_EXPORT CompositorImpl
void SetVisible(bool visible);
void CreateLayerTreeHost();
- void HandlePendingOutputSurfaceRequest();
+ void HandlePendingCompositorFrameSinkRequest();
#if defined(ENABLE_VULKAN)
void CreateVulkanOutputSurface();
@@ -171,11 +172,11 @@ class CONTENT_EXPORT CompositorImpl
size_t num_successive_context_creation_failures_;
- // Whether there is an OutputSurface request pending from the current
- // |host_|. Becomes |true| if RequestNewOutputSurface is called, and |false|
- // if |host_| is deleted or we succeed in creating *and* initializing an
- // OutputSurface (which is essentially the contract with cc).
- bool output_surface_request_pending_;
+ // Whether there is an CompositorFrameSink request pending from the current
+ // |host_|. Becomes |true| if RequestNewCompositorFrameSink is called, and
+ // |false| if |host_| is deleted or we succeed in creating *and* initializing
+ // a CompositorFrameSink (which is essentially the contract with cc).
+ bool compositor_frame_sink_request_pending_;
gpu::Capabilities gpu_capabilities_;
bool needs_begin_frames_;
« no previous file with comments | « content/browser/renderer_host/browser_compositor_view_mac.mm ('k') | content/browser/renderer_host/compositor_impl_android.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698